.. _related-projects-page:

==================
 Related Projects
==================

Schematic Editor
================

`KiCad <https://kicad-pcb.org>`_ is an open source software suite for Electronic Design Automation
(EDA). The programs handle Schematic Capture, and PCB Layout with Gerber output. The suite runs on
Windows, Linux and macOS and is licensed under GNU GPL v3.
